@@ -2,8 +2,6 @@ import argparse
 import os
 import re
 import traceback
-from datetime import datetime
-
 from anadroid.Config import SUPPORTED_PROFILERS, SUPPORTED_TESTING_FRAMEWORKS, SUPPORTED_ANALYZERS, \
     SUPPORTED_INSTRUMENTERS, \
     SUPPORTED_INSTRUMENTATION_TYPES, SUPPORTED_SUITES, SUPPORTED_BUILDING_SYSTEMS
@@ -12,7 +10,6 @@ from anadroid.application.AndroidProject import AndroidProject, BUILD_TYPE, is_a
 from anadroid.application.Application import App
 from anadroid.build.GradleBuilder import GradleBuilder
 from anadroid.device.Device import get_first_connected_device
-
 from anadroid.instrument.JInstInstrumenter import JInstInstrumenter
 from anadroid.instrument.NoneInstrumenter import NoneInstrumenter
 from anadroid.instrument.Types import INSTRUMENTATION_TYPE
@@ -28,6 +25,7 @@ from anadroid.results_analysis.ManafaMethodCoverageAnalyzer import ManafaMethodC
 from anadroid.results_analysis.OldAnaDroidAnalyzer import OldAnaDroidAnalyzer
 from anadroid.results_analysis.SCCAnalyzer import SCCAnalyzer
 from anadroid.testing_framework.AppCrawlerFramework import AppCrawlerFramework
+from anadroid.testing_framework.CustomCommandFramework import CustomCommandFramework
 from anadroid.testing_framework.DroidBotFramework import DroidBotFramework
 from anadroid.testing_framework.JUnitBasedFramework import JUnitBasedFramework
 from anadroid.testing_framework.MonkeyFramework import MonkeyFramework
@@ -35,7 +33,8 @@ from anadroid.testing_framework.MonkeyRunnerFramework import MonkeyRunnerFramewo
 from anadroid.testing_framework.RERANFramework import RERANFramework
 from anadroid.utils.Utils import mega_find, extract_pkg_name_from_apk, get_results_dir, logw, logi, loge, \
     get_resources_dir, get_log_dir
-from pathlib import Path
+
+
 
 class AnaDroid(object):
     """Provides a configurable pipeline to benchmark and analyze Android Projects and Applications.
@@ -62,7 +61,8 @@ class AnaDroid(object):
     def __init__(self, arg1, results_dir=get_results_dir(), profiler=PROFILER.MANAFA,
                  testing_framework=TESTING_FRAMEWORK.MONKEY, device=None, instrumenter=INSTRUMENTER.JINST,
                  analyzer=ANALYZER.OLD_ANADROID_ANALYZER, instrumentation_type=INSTRUMENTATION_TYPE.ANNOTATION,
-                 build_system=BUILD_SYSTEM.GRADLE, build_type=BUILD_TYPE.DEBUG, tests_dir=None, rebuild_apps=False, reinstrument=False, recover_from_last_run=False):
+                 build_system=BUILD_SYSTEM.GRADLE, build_type=BUILD_TYPE.DEBUG, tests_dir=None, rebuild_apps=False,
+                 reinstrument=False, recover_from_last_run=False, test_cmd=None):
         self.device = device if device is not None else get_first_connected_device()
         self.app_projects_ut = []
         self.tests_dir = tests_dir
@@ -77,6 +77,7 @@ class AnaDroid(object):
             self.apps_dir = os.path.realpath(arg1)
             self.app_projects_ut = self.load_projects()
         self.results_dir = results_dir
+        self.test_cmd = test_cmd
         self.instrumentation_type = self.__infer_instrumentation_type(instrumentation_type)
         self.profiler = self.__infer_profiler(profiler)
         self.analyzer = self.__infer_analyzer(analyzer, profiler)
@@ -168,6 +169,11 @@ class AnaDroid(object):
                 return JUnitBasedFramework(profiler=self.profiler, analyzer=self.analyzer)
             elif tf == TESTING_FRAMEWORK.DROIDBOT:
                 return DroidBotFramework(default_workload=True, profiler=self.profiler, analyzer=self.analyzer)
+            elif tf == TESTING_FRAMEWORK.CUSTOM:
+                if self.test_cmd is None:
+                    raise Exception("Unable to execute CustomCommandFramework without providing a command as input")
+                return CustomCommandFramework(default_workload=True, profiler=self.profiler, analyzer=self.analyzer,
+                                              command=self.test_cmd)
             else:
                 return None
         else:
@@ -273,6 +279,17 @@ class AnaDroid(object):
             except Exception as e:
                 loge(traceback.format_exc())
 
+    def exec_command(self):
+        try:
+            self.testing_framework.init_default_workload()
+            self.testing_framework.test_app(self.device, app=None)
+            self.analyzer.analyze_tests(results_dir=self.testing_framework.get_default_test_dir(), **{
+                                                'testing_framework': self.testing_framework,
+                                                })
+        except Exception:
+            loge(traceback.format_exc())
+
+
     def __validate_suite(self, profiler):
         """checks if the selected profiler can be combined with the selected instrumentation tyoe.
         Args:
@@ -328,7 +345,7 @@ class AnaDroid(object):
         has_gradle_right_next = mega_find(dir_path, pattern="build.gradle", maxdepth=4, type_file='f')
         if len(has_gradle_right_next) > 0:
             top_gradle_file = min(has_gradle_right_next, key=len)
-            return os.path.dirname(top_gradle_file)
+            return os.path.dirname(top_gradle_file) if top_gradle_file is not None else None
         return None
 
     def load_projects(self):
