@@ -39,7 +39,8 @@ SUPPORTED_TESTING_FRAMEWORKS = {
     TESTING_FRAMEWORK.APP_CRAWLER,
     TESTING_FRAMEWORK.MONKEY_RUNNER,
     TESTING_FRAMEWORK.JUNIT,
-    TESTING_FRAMEWORK.DROIDBOT
+    TESTING_FRAMEWORK.DROIDBOT,
+    TESTING_FRAMEWORK.CUSTOM
 }
 
 SUPPORTED_BUILDING_SYSTEMS = {
