@@ -1,6 +1,4 @@
 import argparse
-from enum import Enum
-
 from anadroid.Anadroid import AnaDroid
 from anadroid.Types import TESTING_FRAMEWORK, PROFILER, ANALYZER, INSTRUMENTER
 from anadroid.application.AndroidProject import BUILD_TYPE
@@ -21,7 +19,8 @@ def init_PyAnaDroid_from_args(args):
                     tests_dir=args.tests_dir,
                     rebuild_apps=args.rebuild,
                     reinstrument=args.reinstrument,
-                    recover_from_last_run = args.recover
+                    recover_from_last_run=args.recover,
+                    test_cmd=args.command,
                     )
 
 
@@ -41,7 +40,8 @@ def main():
                         choices=[e.value for e in INSTRUMENTATION_TYPE])
     parser.add_argument("-d", "--diretory", default="demoProjects", type=str, help="app(s)' folder")
     parser.add_argument("-bo", "--buildonly", help="just build apps", action='store_true')
-    parser.add_argument("-r", "--record", help="record test", action='store_true')
+    parser.add_argument("-record", "--record", help="record test", action='store_true', default=False)
+    parser.add_argument("-run", "--run_only", help="run only", action='store_true')
     #parser.add_argument("-rt", "--retry", help="retry build if previously failed", action='store_true')
     parser.add_argument("-rb", "--rebuild", help="rebuild apps", action='store_true')
     parser.add_argument("-ri", "--reinstrument", help="reinstrument app", action='store_true')
@@ -53,6 +53,7 @@ def main():
     parser.add_argument("-n", "--package_names", help="package(s) of already installed apps", nargs='+', default=[])
     parser.add_argument("-apk", "--application_packages", help="path of apk(s) to process", nargs='+', default=[])
     parser.add_argument("-rec", "--recover", help="recover progress of the previous run", action='store_true')
+    parser.add_argument("-cmd", "--command", help="test command", type=str, default=None)
     args = parser.parse_args()
     if args.setconnection:
         set_device_conn(args.setconnection, device_id=args.device_serial)
@@ -63,8 +64,10 @@ def main():
     elif args.justanalyze:
         raise NotImplementedError()
         # anadroid.just_analyze()
-    elif args.record:
+    if args.record:
         anadroid.record_test(args.tests_dir)
+    if args.run_only:
+        anadroid.exec_command()
     else:
         anadroid.default_workflow()
 
